Created
November 28, 2017 17:14
-
-
Save meyer9/4b343d1005fea1e8c70d643a33543c83 to your computer and use it in GitHub Desktop.
Difference between Phore headers and PIVX headers
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
diff -ENwbur pivxheaders/accumulatormap.h phoreheaders/accumulatormap.h | |
--- pivxheaders/accumulatormap.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/accumulatormap.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,8 +1,8 @@ | |
// Copyright (c) 2017 The PIVX developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
-#ifndef PIVX_ACCUMULATORMAP_H | |
-#define PIVX_ACCUMULATORMAP_H | |
+#ifndef PHORE_ACCUMULATORMAP_H | |
+#define PHORE_ACCUMULATORMAP_H | |
#include "libzerocoin/Accumulator.h" | |
#include "libzerocoin/Coin.h" | |
@@ -20,4 +20,4 @@ | |
uint256 GetCheckpoint(); | |
void Reset(); | |
}; | |
-#endif //PIVX_ACCUMULATORMAP_H | |
+#endif //PHORE_ACCUMULATORMAP_H | |
diff -ENwbur pivxheaders/accumulators.h phoreheaders/accumulators.h | |
--- pivxheaders/accumulators.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/accumulators.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -2,8 +2,8 @@ | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
-#ifndef PIVX_ACCUMULATORS_H | |
-#define PIVX_ACCUMULATORS_H | |
+#ifndef PHORE_ACCUMULATORS_H | |
+#define PHORE_ACCUMULATORS_H | |
#include "libzerocoin/Accumulator.h" | |
#include "libzerocoin/Denominations.h" | |
@@ -22,4 +22,4 @@ | |
uint32_t GetChecksum(const CBigNum &bnValue); | |
bool InvalidCheckpointRange(int nHeight); | |
-#endif //PIVX_ACCUMULATORS_H | |
+#endif //PHORE_ACCUMULATORS_H | |
diff -ENwbur pivxheaders/activemasternode.h phoreheaders/activemasternode.h | |
--- pivxheaders/activemasternode.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/activemasternode.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -33,7 +33,7 @@ | |
/// Register any Masternode | |
bool Register(CTxIn vin, CService service, CKey key, CPubKey pubKey, CKey keyMasternode, CPubKey pubKeyMasternode, std::string& errorMessage); | |
- /// Get 10000 PIV input that can be used for the Masternode | |
+ /// Get 10000 PHR input that can be used for the Masternode | |
bool GetMasterNodeVin(CTxIn& vin, CPubKey& pubkey, CKey& secretKey, std::string strTxHash, std::string strOutputIndex); | |
bool GetVinFromOutput(COutput out, CTxIn& vin, CPubKey& pubkey, CKey& secretKey); | |
@@ -61,7 +61,7 @@ | |
/// Register remote Masternode | |
bool Register(std::string strService, std::string strKey, std::string strTxHash, std::string strOutputIndex, std::string& errorMessage); | |
- /// Get 10000 PIV input that can be used for the Masternode | |
+ /// Get 10000 PHR input that can be used for the Masternode | |
bool GetMasterNodeVin(CTxIn& vin, CPubKey& pubkey, CKey& secretKey); | |
vector<COutput> SelectCoinsMasternode(); | |
diff -ENwbur pivxheaders/base58.h phoreheaders/base58.h | |
--- pivxheaders/base58.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/base58.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -100,7 +100,7 @@ | |
bool operator>(const CBase58Data& b58) const { return CompareTo(b58) > 0; } | |
}; | |
-/** base58-encoded PIVX addresses. | |
+/** base58-encoded Phore addresses. | |
* Public-key-hash-addresses have version 0 (or 111 testnet). | |
* The data vector contains RIPEMD160(SHA256(pubkey)), where pubkey is the serialized public key. | |
* Script-hash-addresses have version 5 (or 196 testnet). | |
diff -ENwbur pivxheaders/chainparams.h phoreheaders/chainparams.h | |
--- pivxheaders/chainparams.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/chainparams.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -26,7 +26,7 @@ | |
/** | |
* CChainParams defines various tweakable parameters of a given instance of the | |
- * PIVX system. There are three: the main network on which people trade goods | |
+ * Phore system. There are three: the main network on which people trade goods | |
* and services, the public test network which gets reset from time to time and | |
* a regression test mode which is intended for private networks only. It has | |
* minimal difficulty to ensure that blocks can be found instantly. | |
@@ -116,7 +116,6 @@ | |
int Zerocoin_Block_FirstFraudulent() const { return nBlockFirstFraudulent; } | |
int Zerocoin_Block_LastGoodCheckpoint() const { return nBlockLastGoodCheckpoint; } | |
int Zerocoin_StartTime() const { return nZerocoinStartTime; } | |
- int Block_Enforce_Invalid() const { return nBlockEnforceInvalidUTXO; } | |
protected: | |
CChainParams() {} | |
@@ -168,13 +167,11 @@ | |
int nZerocoinHeaderVersion; | |
int64_t nBudget_Fee_Confirmations; | |
int nZerocoinStartHeight; | |
- int nZerocoinStartTime; | |
- | |
int nBlockEnforceSerialRange; | |
int nBlockRecalculateAccumulators; | |
int nBlockFirstFraudulent; | |
int nBlockLastGoodCheckpoint; | |
- int nBlockEnforceInvalidUTXO; | |
+ int nZerocoinStartTime; | |
}; | |
/** | |
diff -ENwbur pivxheaders/chainparamsbase.h phoreheaders/chainparamsbase.h | |
--- pivxheaders/chainparamsbase.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/chainparamsbase.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -9,8 +9,8 @@ | |
#include <vector> | |
/** | |
- * CBaseChainParams defines the base parameters (shared between pivx-cli and pivxd) | |
- * of a given instance of the Pivx system. | |
+ * CBaseChainParams defines the base parameters (shared between phore-cli and phored) | |
+ * of a given instance of the Phore system. | |
*/ | |
class CBaseChainParams | |
{ | |
diff -ENwbur pivxheaders/chainparamsseeds.h phoreheaders/chainparamsseeds.h | |
--- pivxheaders/chainparamsseeds.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/chainparamsseeds.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,259 +1,17 @@ | |
#ifndef BITCOIN_CHAINPARAMSSEEDS_H | |
#define BITCOIN_CHAINPARAMSSEEDS_H | |
/** | |
- * List of fixed seed nodes for the pivx network | |
- * AUTOGENERATED by share/seeds/generate-seeds.py | |
+ * List of fixed seed nodes for the bitcoin network | |
+ * AUTOGENERATED by contrib/seeds/generate-seeds.py | |
* | |
* Each line contains a 16-byte IPv6 address and a port. | |
* IPv4 as well as onion addresses are wrapped inside a IPv6 address accordingly. | |
*/ | |
static SeedSpec6 pnSeed6_main[] = { | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x43}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x44}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x4f}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x41}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x42}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa2, 0xdc, 0x37, 0xcf}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x53}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x40}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xd3}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xca}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x4a}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x97, 0x50, 0x02, 0xf6}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x42}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x51}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x51}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x59}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xeb}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x6d}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xed, 0xd8}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x70}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x70}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xff, 0xe7, 0xa2}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xff, 0xe7, 0x3e}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x55}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xe5}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0xf1, 0xd9, 0x7e}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x73}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x57, 0x5c, 0x42, 0x8a}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xc6}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x5d}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x46}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xed, 0xd4}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x48, 0x31, 0xb8, 0xce}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x36, 0xb7, 0x0a, 0x30}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x6f}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xe4}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x97, 0x50, 0x02, 0xf9}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb9, 0x2d, 0xc0, 0x0f}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0x9a, 0x5e, 0x7a}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x2d, 0x37, 0xc3, 0xf3}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x36, 0x59, 0x15, 0x2c}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0x63, 0xd9, 0x5d}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x65}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0x63, 0xd9, 0x63}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x9e, 0x45, 0xee, 0xde}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x5f}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x7a}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x19, 0xd0}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x05, 0x27, 0x08, 0xf1}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x97, 0x63}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x79}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x48, 0x31, 0xb8, 0xce}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xed, 0xd2}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xee, 0xbc, 0x2c}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xc8}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x70}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x97, 0x68}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0x63, 0xd9, 0x5e}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x97, 0x59}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x9e, 0x45, 0xee, 0xeb}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x19, 0xd5}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x68}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x44, 0xe0, 0xf0, 0x0d}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x54, 0xea, 0x34, 0xbe}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x9e, 0x45, 0x0c, 0xff}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x42, 0xac, 0x21, 0xf8}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb2, 0x11, 0xae, 0x63}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb0, 0x7e, 0xfc, 0x0b}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x6f}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xec, 0xb7, 0x1d}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x6c}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x97, 0x50, 0x02, 0xf2}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x92, 0x94, 0x4e, 0x96}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xad, 0xf5, 0x9e, 0x08}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x82, 0xd3, 0x58, 0x5e}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x8b, 0x3b, 0x8d, 0x11}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0x9a, 0x52, 0x43}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x4e, 0xeb, 0x18, 0xac}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x48, 0x18, 0x58, 0x5c}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xd4, 0x18, 0x62, 0xd9}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x6e}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc1, 0x6f, 0x88, 0xa2}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb2, 0xfe, 0x17, 0x6f}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb2, 0xfe, 0x17, 0x6f}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xd4, 0x70, 0x77, 0x8c}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x47, 0xc0, 0xd2, 0x9b}, 51472}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa6, 0xaa, 0x27, 0xc4}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x31, 0xec, 0xf1}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x40, 0x86, 0x77}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x75, 0x1c, 0xb6}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xfc, 0x01, 0xb9}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xda, 0x20, 0xdb}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xb5, 0xbc, 0xf5}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd5, 0x3b, 0x78}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd5, 0x9e, 0xba}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x58, 0x19, 0xca}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x9f, 0xd1, 0xdf}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x5f, 0xcb, 0x35}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x32, 0xd1, 0xa9}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x6a, 0x44, 0xbc}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd3, 0x2e, 0x13}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xed, 0x95, 0x1c}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x5f, 0x1d, 0x22}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd9, 0xf6, 0x04}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xf9, 0xfe, 0x6d}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x54, 0xfc, 0x52}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x44, 0xde, 0xda}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x45, 0xff, 0x4b}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xcd, 0xa6, 0x64}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xb2, 0x66, 0x92}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xdd, 0xf3, 0x98}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xb3, 0x49, 0xb1}, 51472}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x1d, 0xd3, 0x1a}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0xc7, 0x54, 0x29, 0x09, 0xa7, 0x7e, 0x0d, 0x5a, 0xb5, 0x2d}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0xe8, 0x58, 0x79, 0xa6, 0xad, 0xd2, 0x6b, 0x67, 0xa0, 0x89}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x7e, 0x0a, 0x3b, 0xa8, 0x19, 0xa4, 0x76, 0x84, 0x07, 0xf8}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x72, 0xb7, 0x86, 0x77, 0x38, 0xf3, 0x3a, 0xa5, 0xa1, 0x8a}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x47, 0xaa, 0xfa, 0xe5, 0x5a, 0x4d, 0xe9, 0x08, 0x4b, 0xa5}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x09, 0x86, 0x77, 0x87, 0xfe, 0x2a, 0x83, 0x6e, 0x95, 0x86}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x34, 0xd7, 0x0c, 0x87, 0xb9, 0x0d, 0xa5, 0xd1, 0xa3, 0xe6}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x2f, 0xd3, 0xa6, 0x6b, 0xd1, 0x7c, 0xd9, 0xd2, 0xfc, 0x05}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x1b, 0x49, 0x3c, 0xa7, 0xcb, 0xe0, 0xaa, 0xed, 0x16, 0xf8}, 51472}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x96, 0xeb, 0xb6, 0xfe, 0xe7, 0x80, 0x0a, 0x6f, 0x48, 0x3f}, 51472}}; | |
+ {{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x59,0xde,0xe9,0xde}, 11771} | |
+}; | |
static SeedSpec6 pnSeed6_test[] = { | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x43}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x44}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x4f}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x41}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x42}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa2, 0xdc, 0x37, 0xcf}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x53}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x40}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xd3}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xca}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x4a}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x97, 0x50, 0x02, 0xf6}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x42}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x51}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x51}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x59}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xeb}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x6d}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xed, 0xd8}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x70}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x70}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xff, 0xe7, 0xa2}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xff, 0xe7, 0x3e}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x55}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xe5}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0xf1, 0xd9, 0x7e}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x73}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x57, 0x5c, 0x42, 0x8a}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xc6}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x5d}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x46}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xed, 0xd4}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x48, 0x31, 0xb8, 0xce}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x36, 0xb7, 0x0a, 0x30}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x6f}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xe4}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x97, 0x50, 0x02, 0xf9}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb9, 0x2d, 0xc0, 0x0f}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0x9a, 0x5e, 0x7a}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x2d, 0x37, 0xc3, 0xf3}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x36, 0x59, 0x15, 0x2c}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0x63, 0xd9, 0x5d}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xee, 0x65}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0x63, 0xd9, 0x63}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x9e, 0x45, 0xee, 0xde}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x5f}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x7a}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x19, 0xd0}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x05, 0x27, 0x08, 0xf1}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x97, 0x63}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x79}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x48, 0x31, 0xb8, 0xce}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xed, 0xd2}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xee, 0xbc, 0x2c}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xbd, 0xc8}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x70}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x97, 0x68}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc0, 0x63, 0xd9, 0x5e}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x97, 0x59}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x9e, 0x45, 0xee, 0xeb}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0x19, 0xd5}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x25, 0x3b, 0xd1, 0x68}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x44, 0xe0, 0xf0, 0x0d}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x54, 0xea, 0x34, 0xbe}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x9e, 0x45, 0x0c, 0xff}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x42, 0xac, 0x21, 0xf8}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb2, 0x11, 0xae, 0x63}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb0, 0x7e, 0xfc, 0x0b}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x6f}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0xec, 0xb7, 0x1d}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x6c}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x97, 0x50, 0x02, 0xf2}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x92, 0x94, 0x4e, 0x96}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xad, 0xf5, 0x9e, 0x08}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x82, 0xd3, 0x58, 0x5e}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x8b, 0x3b, 0x8d, 0x11}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x68, 0x9a, 0x52, 0x43}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x4e, 0xeb, 0x18, 0xac}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x48, 0x18, 0x58, 0x5c}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xd4, 0x18, 0x62, 0xd9}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0x84, 0xb0, 0x6e}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xc1, 0x6f, 0x88, 0xa2}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb2, 0xfe, 0x17, 0x6f}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb2, 0xfe, 0x17, 0x6f}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xd4, 0x70, 0x77, 0x8c}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0x47, 0xc0, 0xd2, 0x9b}, 51474}, | |
- {{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa6, 0xaa, 0x27, 0xc4}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x31, 0xec, 0xf1}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x40, 0x86, 0x77}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x75, 0x1c, 0xb6}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xfc, 0x01, 0xb9}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xda, 0x20, 0xdb}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xb5, 0xbc, 0xf5}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd5, 0x3b, 0x78}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd5, 0x9e, 0xba}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x58, 0x19, 0xca}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x9f, 0xd1, 0xdf}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x5f, 0xcb, 0x35}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x32, 0xd1, 0xa9}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x6a, 0x44, 0xbc}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd3, 0x2e, 0x13}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xed, 0x95, 0x1c}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x5f, 0x1d, 0x22}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xd9, 0xf6, 0x04}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xf9, 0xfe, 0x6d}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x54, 0xfc, 0x52}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x44, 0xde, 0xda}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x45, 0xff, 0x4b}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xcd, 0xa6, 0x64}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xb2, 0x66, 0x92}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xdd, 0xf3, 0x98}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0xb3, 0x49, 0xb1}, 51474}, | |
- {{0x20, 0x01, 0x04, 0x70, 0x1f, 0x07, 0x00, 0x4e, 0x50, 0x54, 0x00, 0xff, 0xfe, 0x1d, 0xd3, 0x1a}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0xc7, 0x54, 0x29, 0x09, 0xa7, 0x7e, 0x0d, 0x5a, 0xb5, 0x2d}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0xe8, 0x58, 0x79, 0xa6, 0xad, 0xd2, 0x6b, 0x67, 0xa0, 0x89}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x7e, 0x0a, 0x3b, 0xa8, 0x19, 0xa4, 0x76, 0x84, 0x07, 0xf8}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x72, 0xb7, 0x86, 0x77, 0x38, 0xf3, 0x3a, 0xa5, 0xa1, 0x8a}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x47, 0xaa, 0xfa, 0xe5, 0x5a, 0x4d, 0xe9, 0x08, 0x4b, 0xa5}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x09, 0x86, 0x77, 0x87, 0xfe, 0x2a, 0x83, 0x6e, 0x95, 0x86}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x34, 0xd7, 0x0c, 0x87, 0xb9, 0x0d, 0xa5, 0xd1, 0xa3, 0xe6}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x2f, 0xd3, 0xa6, 0x6b, 0xd1, 0x7c, 0xd9, 0xd2, 0xfc, 0x05}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x1b, 0x49, 0x3c, 0xa7, 0xcb, 0xe0, 0xaa, 0xed, 0x16, 0xf8}, 51474}, | |
- {{0xfd, 0x87, 0xd8, 0x7e, 0xeb, 0x43, 0x96, 0xeb, 0xb6, 0xfe, 0xe7, 0x80, 0x0a, 0x6f, 0x48, 0x3f}, 51474}}; | |
+ {{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x59,0xde,0xe9,0xde}, 11772} | |
+}; | |
#endif // BITCOIN_CHAINPARAMSSEEDS_H | |
diff -ENwbur pivxheaders/checkpoints.h phoreheaders/checkpoints.h | |
--- pivxheaders/checkpoints.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/checkpoints.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -27,7 +27,7 @@ | |
}; | |
//! Returns true if block passes checkpoint checks | |
-bool CheckBlock(int nHeight, const uint256& hash, bool fMatchesCheckpoint = false); | |
+bool CheckBlock(int nHeight, const uint256& hash); | |
//! Return conservative estimate of total number of blocks, 0 if unknown | |
int GetTotalBlocksEstimate(); | |
diff -ENwbur pivxheaders/clientversion.h phoreheaders/clientversion.h | |
--- pivxheaders/clientversion.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/clientversion.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,4 +1,5 @@ | |
// Copyright (c) 2009-2014 The Bitcoin developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
@@ -6,21 +7,21 @@ | |
#define BITCOIN_CLIENTVERSION_H | |
#if defined(HAVE_CONFIG_H) | |
-#include "config/pivx-config.h" | |
+#include "config/phore-config.h" | |
#else | |
/** | |
* client versioning and copyright year | |
*/ | |
-//! These need to be macros, as clientversion.cpp's and pivx*-res.rc's voodoo requires it | |
-#define CLIENT_VERSION_MAJOR 3 | |
-#define CLIENT_VERSION_MINOR 0 | |
-#define CLIENT_VERSION_REVISION 99 | |
+//! These need to be macros, as clientversion.cpp's and phore*-res.rc's voodoo requires it | |
+#define CLIENT_VERSION_MAJOR 1 | |
+#define CLIENT_VERSION_MINOR 1 | |
+#define CLIENT_VERSION_REVISION 0 | |
#define CLIENT_VERSION_BUILD 0 | |
//! Set to true for release, false for prerelease or test build | |
-#define CLIENT_VERSION_IS_RELEASE false | |
+#define CLIENT_VERSION_IS_RELEASE true | |
/** | |
* Copyright year (2009-this) | |
@@ -38,10 +39,10 @@ | |
#define DO_STRINGIZE(X) #X | |
//! Copyright string used in Windows .rc files | |
-#define COPYRIGHT_STR "2009-" STRINGIZE(COPYRIGHT_YEAR) " The Bitcoin Core Developers, 2014-" STRINGIZE(COPYRIGHT_YEAR) " The Dash Core Developers, 2015-" STRINGIZE(COPYRIGHT_YEAR) " The PIVX Core Developers" | |
+#define COPYRIGHT_STR "2009-" STRINGIZE(COPYRIGHT_YEAR) " The Bitcoin Core Developers, 2014-" STRINGIZE(COPYRIGHT_YEAR) " The Dash Core Developers, 2015-" STRINGIZE(COPYRIGHT_YEAR) " The PIVX Core Developers, 2017-" STRINGIZE(COPYRIGHT_YEAR) " The Phore Core Developers" | |
/** | |
- * pivxd-res.rc includes this file, but it cannot cope with real c++ code. | |
+ * phored-res.rc includes this file, but it cannot cope with real c++ code. | |
* WINDRES_PREPROC is defined to indicate that its pre-processor is running. | |
* Anything other than a define should be guarded below. | |
*/ | |
diff -ENwbur pivxheaders/coins.h phoreheaders/coins.h | |
--- pivxheaders/coins.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/coins.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -20,7 +20,7 @@ | |
/** | |
- ****Note - for PIVX we added fCoinStake to the 2nd bit. Keep in mind when reading the following and adjust as needed. | |
+ ****Note - for Phore we added fCoinStake to the 2nd bit. Keep in mind when reading the following and adjust as needed. | |
* Pruned version of CTransaction: only retains metadata and unspent transaction outputs | |
* | |
* Serialized format: | |
@@ -457,7 +457,7 @@ | |
unsigned int GetCacheSize() const; | |
/** | |
- * Amount of pivx coming in to a transaction | |
+ * Amount of phore coming in to a transaction | |
* Note that lightweight clients may not know anything besides the hash of previous transactions, | |
* so may not be able to calculate this. | |
* | |
diff -ENwbur pivxheaders/compat.h phoreheaders/compat.h | |
--- pivxheaders/compat.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/compat.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -7,7 +7,7 @@ | |
#define BITCOIN_COMPAT_H | |
#if defined(HAVE_CONFIG_H) | |
-#include "config/pivx-config.h" | |
+#include "config/phore-config.h" | |
#endif | |
#ifdef WIN32 | |
diff -ENwbur pivxheaders/hash.h phoreheaders/hash.h | |
--- pivxheaders/hash.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/hash.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -2,6 +2,7 @@ | |
// Copyright (c) 2009-2014 The Bitcoin developers | |
// Copyright (c) 2014-2015 The Dash developers | |
// Copyright (c) 2015-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
diff -ENwbur pivxheaders/main.h phoreheaders/main.h | |
--- pivxheaders/main.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/main.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -2,6 +2,7 @@ | |
// Copyright (c) 2009-2014 The Bitcoin developers | |
// Copyright (c) 2014-2015 The Dash developers | |
// Copyright (c) 2015-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
@@ -9,7 +10,7 @@ | |
#define BITCOIN_MAIN_H | |
#if defined(HAVE_CONFIG_H) | |
-#include "config/pivx-config.h" | |
+#include "config/phore-config.h" | |
#endif | |
#include "amount.h" | |
@@ -83,7 +84,7 @@ | |
/** The pre-allocation chunk size for rev?????.dat files (since 0.8) */ | |
static const unsigned int UNDOFILE_CHUNK_SIZE = 0x100000; // 1 MiB | |
/** Coinbase transaction outputs can only be spent after this number of new blocks (network rule) */ | |
-static const int COINBASE_MATURITY = 100; | |
+static const int COINBASE_MATURITY = 50; | |
/** Threshold for nLockTime: below this value it is interpreted as block number, otherwise as UNIX timestamp. */ | |
static const unsigned int LOCKTIME_THRESHOLD = 500000000; // Tue Nov 5 00:53:20 1985 UTC | |
/** Maximum number of script-checking threads allowed */ | |
@@ -205,7 +206,7 @@ | |
/** Initialize a new block tree database + block data on disk */ | |
bool InitBlockIndex(); | |
/** Load the block tree and coins database from disk */ | |
-bool LoadBlockIndex(std::string& strError); | |
+bool LoadBlockIndex(); | |
/** Unload database information */ | |
void UnloadBlockIndex(); | |
/** See whether the protocol update is enforced for connected nodes */ | |
@@ -371,10 +372,9 @@ | |
bool IsBlockHashInChain(const uint256& hashBlock); | |
void PopulateInvalidOutPointMap(); | |
bool ValidOutPoint(const COutPoint out, int nHeight); | |
-void RecalculateZPIVSpent(); | |
-void RecalculateZPIVMinted(); | |
-bool RecalculatePIVSupply(int nHeightStart); | |
-bool ReindexAccumulators(list<uint256>& listMissingCheckpoints, string& strError); | |
+void RecalculateZPHRSpent(); | |
+void RecalculateZPHRMinted(); | |
+bool RecalculatePHRSupply(int nHeightStart); | |
/** | |
diff -ENwbur pivxheaders/masternode-budget.h phoreheaders/masternode-budget.h | |
--- pivxheaders/masternode-budget.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/masternode-budget.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -360,7 +360,7 @@ | |
//check to see if we should vote on this | |
void AutoCheck(); | |
- //total pivx paid out by this budget | |
+ //total phore paid out by this budget | |
CAmount GetTotalPayout(); | |
//vote on this finalized budget as a masternode | |
void SubmitVote(); | |
diff -ENwbur pivxheaders/masternode.h phoreheaders/masternode.h | |
--- pivxheaders/masternode.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/masternode.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -100,7 +100,7 @@ | |
}; | |
// | |
-// The Masternode Class. For managing the Obfuscation process. It contains the input of the 10000 PIV, signature to prove | |
+// The Masternode Class. For managing the Obfuscation process. It contains the input of the 10000 PHR, signature to prove | |
// it's the one who own that ip address and code for calculating the payment election. | |
// | |
class CMasternode | |
diff -ENwbur pivxheaders/netbase.h phoreheaders/netbase.h | |
--- pivxheaders/netbase.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/netbase.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -6,7 +6,7 @@ | |
#define BITCOIN_NETBASE_H | |
#if defined(HAVE_CONFIG_H) | |
-#include "config/pivx-config.h" | |
+#include "config/phore-config.h" | |
#endif | |
#include "compat.h" | |
diff -ENwbur pivxheaders/obfuscation.h phoreheaders/obfuscation.h | |
--- pivxheaders/obfuscation.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/obfuscation.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -247,7 +247,7 @@ | |
class CObfuScationSigner | |
{ | |
public: | |
- /// Is the inputs associated with this public key? (and there is 10000 PIV - checking if valid masternode) | |
+ /// Is the inputs associated with this public key? (and there is 10000 PHR - checking if valid masternode) | |
bool IsVinAssociatedWithPubkey(CTxIn& vin, CPubKey& pubkey); | |
/// Set the private/public key values, returns true if successful | |
bool GetKeysFromSecret(std::string strSecret, CKey& keyRet, CPubKey& pubkeyRet); | |
@@ -493,7 +493,7 @@ | |
void GetDenominationsToString(int nDenom, std::string& strDenom); | |
- /// Get the denominations for a specific amount of pivx. | |
+ /// Get the denominations for a specific amount of phore. | |
int GetDenominationsByAmount(CAmount nAmount, int nDenomTarget = 0); // is not used anymore? | |
int GetDenominationsByAmounts(std::vector<CAmount>& vecAmount); | |
diff -ENwbur pivxheaders/rpcserver.h phoreheaders/rpcserver.h | |
--- pivxheaders/rpcserver.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/rpcserver.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -96,7 +96,7 @@ | |
}; | |
/** | |
- * PIVX RPC command dispatcher. | |
+ * Phore RPC command dispatcher. | |
*/ | |
class CRPCTable | |
{ | |
diff -ENwbur pivxheaders/spork.h phoreheaders/spork.h | |
--- pivxheaders/spork.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/spork.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -36,7 +36,7 @@ | |
#define SPORK_8_MASTERNODE_PAYMENT_ENFORCEMENT 10007 | |
#define SPORK_9_MASTERNODE_BUDGET_ENFORCEMENT 10008 | |
#define SPORK_10_MASTERNODE_PAY_UPDATED_NODES 10009 | |
-//#define SPORK_11_LOCK_INVALID_UTXO 10010 | |
+#define SPORK_11_LOCK_INVALID_UTXO 10010 | |
//#define SPORK_12_RECONSIDER_BLOCKS 10011 | |
#define SPORK_13_ENABLE_SUPERBLOCKS 10012 | |
#define SPORK_14_NEW_PROTOCOL_ENFORCEMENT 10013 | |
@@ -45,12 +45,12 @@ | |
#define SPORK_2_SWIFTTX_DEFAULT 978307200 //2001-1-1 | |
#define SPORK_3_SWIFTTX_BLOCK_FILTERING_DEFAULT 1424217600 //2015-2-18 | |
-#define SPORK_5_MAX_VALUE_DEFAULT 1000 //1000 PIV | |
+#define SPORK_5_MAX_VALUE_DEFAULT 1000 //1000 PHR | |
#define SPORK_7_MASTERNODE_SCANNING_DEFAULT 978307200 //2001-1-1 | |
#define SPORK_8_MASTERNODE_PAYMENT_ENFORCEMENT_DEFAULT 4070908800 //OFF | |
#define SPORK_9_MASTERNODE_BUDGET_ENFORCEMENT_DEFAULT 4070908800 //OFF | |
#define SPORK_10_MASTERNODE_PAY_UPDATED_NODES_DEFAULT 4070908800 //OFF | |
-//#define SPORK_11_LOCK_INVALID_UTXO_DEFAULT 4070908800 //OFF - NOTE: this is block height not time! | |
+#define SPORK_11_LOCK_INVALID_UTXO_DEFAULT 4070908800 //OFF - NOTE: this is block height not time! | |
#define SPORK_13_ENABLE_SUPERBLOCKS_DEFAULT 4070908800 //OFF | |
#define SPORK_14_NEW_PROTOCOL_ENFORCEMENT_DEFAULT 4070908800 //OFF | |
#define SPORK_15_NEW_PROTOCOL_ENFORCEMENT_2_DEFAULT 4070908800 //OFF | |
diff -ENwbur pivxheaders/sporkdb.h phoreheaders/sporkdb.h | |
--- pivxheaders/sporkdb.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/sporkdb.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -2,8 +2,8 @@ | |
// Distributed under the MIT/X11 software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
-#ifndef PIVX_CSPORKDB_H | |
-#define PIVX_CSPORKDB_H | |
+#ifndef PHORE_CSPORKDB_H | |
+#define PHORE_CSPORKDB_H | |
#include <boost/filesystem/path.hpp> | |
#include "leveldbwrapper.h" | |
@@ -25,4 +25,4 @@ | |
}; | |
-#endif //PIVX_CSPORKDB_H | |
+#endif //PHORE_CSPORKDB_H | |
diff -ENwbur pivxheaders/txdb.h phoreheaders/txdb.h | |
--- pivxheaders/txdb.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/txdb.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,6 +1,7 @@ | |
// Copyright (c) 2009-2010 Satoshi Nakamoto | |
// Copyright (c) 2009-2014 The Bitcoin developers | |
// Copyright (c) 2016-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
diff -ENwbur pivxheaders/txmempool.h phoreheaders/txmempool.h | |
--- pivxheaders/txmempool.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/txmempool.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,6 +1,7 @@ | |
// Copyright (c) 2009-2010 Satoshi Nakamoto | |
// Copyright (c) 2009-2014 The Bitcoin developers | |
// Copyright (c) 2016-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
diff -ENwbur pivxheaders/uint256.h phoreheaders/uint256.h | |
--- pivxheaders/uint256.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/uint256.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -2,6 +2,7 @@ | |
// Copyright (c) 2009-2014 The Bitcoin developers | |
// Copyright (c) 2014-2015 The Dash developers | |
// Copyright (c) 2015-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
diff -ENwbur pivxheaders/uint512.h phoreheaders/uint512.h | |
--- pivxheaders/uint512.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/uint512.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,4 +1,5 @@ | |
// Copyright (c) 2017 The PIVX Core developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
diff -ENwbur pivxheaders/utiltime.h phoreheaders/utiltime.h | |
--- pivxheaders/utiltime.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/utiltime.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,6 +1,7 @@ | |
// Copyright (c) 2009-2010 Satoshi Nakamoto | |
// Copyright (c) 2009-2014 The Bitcoin developers | |
// Copyright (c) 2016-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
diff -ENwbur pivxheaders/version.h phoreheaders/version.h | |
--- pivxheaders/version.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/version.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,6 +1,7 @@ | |
// Copyright (c) 2012-2014 The Bitcoin developers | |
// Copyright (c) 2014-2015 The Dash developers | |
// Copyright (c) 2015-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
@@ -11,17 +12,17 @@ | |
* network protocol versioning | |
*/ | |
-static const int PROTOCOL_VERSION = 70912; | |
+static const int PROTOCOL_VERSION = 70002; | |
//! initial proto version, to be increased after version/verack negotiation | |
static const int INIT_PROTO_VERSION = 209; | |
//! In this version, 'getheaders' was introduced. | |
-static const int GETHEADERS_VERSION = 70077; | |
+static const int GETHEADERS_VERSION = 70000; | |
//! disconnect from peers older than this proto version | |
-static const int MIN_PEER_PROTO_VERSION_BEFORE_ENFORCEMENT = 70911; | |
-static const int MIN_PEER_PROTO_VERSION_AFTER_ENFORCEMENT = 70912; | |
+static const int MIN_PEER_PROTO_VERSION_BEFORE_ENFORCEMENT = 70002; | |
+static const int MIN_PEER_PROTO_VERSION_AFTER_ENFORCEMENT = 70002; | |
//! nTime field added to CAddress, starting with this version; | |
//! if possible, avoid requesting addresses nodes older than this | |
@@ -34,7 +35,7 @@ | |
static const int MEMPOOL_GD_VERSION = 60002; | |
//! "filter*" commands are disabled without NODE_BLOOM after and including this version | |
-static const int NO_BLOOM_VERSION = 70005; | |
+static const int NO_BLOOM_VERSION = 70000; | |
#endif // BITCOIN_VERSION_H | |
diff -ENwbur pivxheaders/walletdb.h phoreheaders/walletdb.h | |
--- pivxheaders/walletdb.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/walletdb.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -1,6 +1,7 @@ | |
// Copyright (c) 2009-2010 Satoshi Nakamoto | |
// Copyright (c) 2009-2013 The Bitcoin developers | |
// Copyright (c) 2016-2017 The PIVX developers | |
+// Copyright (c) 2017 The Phore developers | |
// Distributed under the MIT/X11 software license, see the accompanying | |
// file COPYING or http://www.opensource.org/licenses/mit-license.php. | |
Sign up for free
to join this conversation on GitHub.
Already have an account?
Sign in to comment
diff -ENwbur pivxheaders/rpcprotocol.h phoreheaders/rpcprotocol.h | |
--- pivxheaders/rpcprotocol.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/rpcprotocol.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -30,7 +30,7 @@ | |
HTTP_SERVICE_UNAVAILABLE = 503, | |
}; | |
//! PIVX RPC error codes | |
enum RPCErrorCode { | |
//! Standard JSON-RPC 2.0 errors | |
RPC_INVALID_REQUEST = -32600, | |
@@ -59,7 +59,7 @@ | |
RPC_TRANSACTION_ALREADY_IN_CHAIN = RPC_VERIFY_ALREADY_IN_CHAIN, | |
//! P2P client errors | |
- RPC_CLIENT_NOT_CONNECTED = -9, //! PIVX is not connected | |
+ RPC_CLIENT_NOT_CONNECTED = -9, //! Phore is not connected | |
RPC_CLIENT_IN_INITIAL_DOWNLOAD = -10, //! Still downloading initial blocks | |
RPC_CLIENT_NODE_ALREADY_ADDED = -23, //! Node is already added | |
RPC_CLIENT_NODE_NOT_ADDED = -24, //! Node has not been added before | |
@@ -30,7 +30,7 @@ | |
HTTP_SERVICE_UNAVAILABLE = 503, | |
}; | |
-//! PIVX RPC error codes | |
+//! Phore RPC error codes | |
enum RPCErrorCode { | |
//! Standard JSON-RPC 2.0 errors | |
diff -ENwbur pivxheaders/util.h phoreheaders/util.h | |
--- pivxheaders/util.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/util.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -13,7 +13,7 @@ | |
#define BITCOIN_UTIL_H | |
#if defined(HAVE_CONFIG_H) | |
-#include "config/pivx-config.h" | |
+#include "config/phore-config.h" | |
#endif | |
#include "compat.h" | |
@@ -29,7 +29,7 @@ | |
#include <boost/filesystem/path.hpp> | |
#include <boost/thread/exceptions.hpp> | |
//PIVX only features | |
extern bool fMasterNode; | |
extern bool fLiteMode; | |
@@ -38,7 +38,7 @@ | |
extern int nZeromintPercentage; | |
extern const int64_t AUTOMINT_DELAY; | |
extern int nPreferredDenom; | |
-extern int nAnonymizePivxAmount; | |
+extern int nAnonymizePhoreAmount; | |
extern int nLiquidityProvider; | |
extern bool fEnableZeromint; | |
extern int64_t enforceMasternodePaymentsTime; | |
@@ -215,7 +215,7 @@ | |
template <typename Callable> | |
void LoopForever(const char* name, Callable func, int64_t msecs) | |
{ | |
- std::string s = strprintf("pivx-%s", name); | |
+ std::string s = strprintf("phore-%s", name); | |
RenameThread(s.c_str()); | |
LogPrintf("%s thread start\n", name); | |
try { | |
@@ -241,7 +241,7 @@ | |
template <typename Callable> | |
void TraceThread(const char* name, Callable func) | |
{ | |
- std::string s = strprintf("pivx-%s", name); | |
+ std::string s = strprintf("phore-%s", name); | |
RenameThread(s.c_str()); | |
try { | |
LogPrintf("%s thread start\n", name); | |
@@ -29,7 +29,7 @@ | |
#include <boost/filesystem/path.hpp> | |
#include <boost/thread/exceptions.hpp> | |
-//PIVX only features | |
+//Phore only features | |
extern bool fMasterNode; | |
extern bool fLiteMode; | |
diff -ENwbur pivxheaders/wallet.h phoreheaders/wallet.h | |
--- pivxheaders/wallet.h 2017-11-28 09:12:03.000000000 -0800 | |
+++ phoreheaders/wallet.h 2017-11-28 09:12:27.000000000 -0800 | |
@@ -80,29 +80,28 @@ | |
ALL_COINS = 1, | |
ONLY_DENOMINATED = 2, | |
ONLY_NOT10000IFMN = 3, | |
- ONLY_NONDENOMINATED_NOT10000IFMN = 4, // ONLY_NONDENOMINATED and not 10000 PIV at the same time | |
+ ONLY_NONDENOMINATED_NOT10000IFMN = 4, // ONLY_NONDENOMINATED and not 10000 PHR at the same time | |
ONLY_10000 = 5, // find masternode outputs including locked ones (use with caution) | |
STAKABLE_COINS = 6 // UTXO's that are valid for staking | |
}; | |
// Possible states for zPIV send | |
enum ZerocoinSpendStatus { | |
- ZPIV_SPEND_OKAY = 0, // No error | |
- ZPIV_SPEND_ERROR = 1, // Unspecified class of errors, more details are (hopefully) in the returning text | |
- ZPIV_WALLET_LOCKED = 2, // Wallet was locked | |
- ZPIV_COMMIT_FAILED = 3, // Commit failed, reset status | |
- ZPIV_ERASE_SPENDS_FAILED = 4, // Erasing spends during reset failed | |
- ZPIV_ERASE_NEW_MINTS_FAILED = 5, // Erasing new mints during reset failed | |
- ZPIV_TRX_FUNDS_PROBLEMS = 6, // Everything related to available funds | |
- ZPIV_TRX_CREATE = 7, // Everything related to create the transaction | |
- ZPIV_TRX_CHANGE = 8, // Everything related to transaction change | |
- ZPIV_TXMINT_GENERAL = 9, // General errors in MintToTxIn | |
- ZPIV_INVALID_COIN = 10, // Selected mint coin is not valid | |
- ZPIV_FAILED_ACCUMULATOR_INITIALIZATION = 11, // Failed to initialize witness | |
- ZPIV_INVALID_WITNESS = 12, // Spend coin transaction did not verify | |
- ZPIV_BAD_SERIALIZATION = 13, // Transaction verification failed | |
- ZPIV_SPENT_USED_ZPIV = 14, // Coin has already been spend | |
- ZPIV_TX_TOO_LARGE = 15 // The transaction is larger than the max tx size | |
+ ZPHR_SPEND_OKAY = 0, // No error | |
+ ZPHR_SPEND_ERROR = 1, // Unspecified class of errors, more details are (hopefully) in the returning text | |
+ ZPHR_WALLET_LOCKED = 2, // Wallet was locked | |
+ ZPHR_COMMIT_FAILED = 3, // Commit failed, reset status | |
+ ZPHR_ERASE_SPENDS_FAILED = 4, // Erasing spends during reset failed | |
+ ZPHR_ERASE_NEW_MINTS_FAILED = 5, // Erasing new mints during reset failed | |
+ ZPHR_TRX_FUNDS_PROBLEMS = 6, // Everything related to available funds | |
+ ZPHR_TRX_CREATE = 7, // Everything related to create the transaction | |
+ ZPHR_TRX_CHANGE = 8, // Everything related to transaction change | |
+ ZPHR_TXMINT_GENERAL = 9, // General errors in MintToTxIn | |
+ ZPHR_INVALID_COIN = 10, // Selected mint coin is not valid | |
+ ZPHR_FAILED_ACCUMULATOR_INITIALIZATION = 11, // Failed to initialize witness | |
+ ZPHR_INVALID_WITNESS = 12, // Spend coin transaction did not verify | |
+ ZPHR_BAD_SERIALIZATION = 13, // Transaction verification failed | |
+ ZPHR_SPENT_USED_ZPHR = 14 // Coin has already been spend | |
}; | |
struct CompactTallyItem { | |
@@ -207,7 +206,7 @@ | |
std::string ResetMintZerocoin(bool fExtendedSearch); | |
std::string ResetSpentZerocoin(); | |
void ReconsiderZerocoins(std::list<CZerocoinMint>& listMintsRestored); | |
- void ZPivBackupWallet(); | |
+ void ZPhrBackupWallet(); | |
/** Zerocin entry changed. | |
* @note called with lock cs_wallet held. | |
@@ -287,7 +286,7 @@ | |
// Stake Settings | |
nHashDrift = 45; | |
- nStakeSplitThreshold = 2000; | |
+ nStakeSplitThreshold = 500; | |
nHashInterval = 22; | |
nStakeSetUpdateTime = 300; // 5 minutes | |
@@ -310,7 +309,7 @@ | |
return fEnableZeromint; | |
} | |
- void setZPivAutoBackups(bool fEnabled) | |
+ void setZPhrAutoBackups(bool fEnabled) | |
{ | |
fBackupMints = fEnabled; | |
} | |
@@ -80,29 +80,28 @@ | |
STAKABLE_COINS = 6 // UTXO's that are valid for staking | |
}; | |
-// Possible states for zPIV send | |
+// Possible states for zPHR send | |
enum ZerocoinSpendStatus { | |